package com.ygtx.system.mapper;

import java.util.List;
import com.ygtx.system.domain.SysPostHomePage;

/**
 * 首页配置 数据层
 * 
 * @author ruoyi
 */
public interface SysPostHomePageMapper
{
    /**
     * 查询首页配置数据集合
     * 
     * @param sysPostHomePage 首页配置信息
     * @return 首页配置数据集合
     */
    public List<SysPostHomePage> selectSysPostHomePageList(SysPostHomePage sysPostHomePage);

    /**
     * 通过ID查询首页配置信息
     * 
     * @param id 配置ID
     * @return 首页配置信息
     */
    public SysPostHomePage selectSysPostHomePageById(Long id);

    /**
     * 新增首页配置信息
     * 
     * @param sysPostHomePage 首页配置信息
     * @return 结果
     */
    public int insertSysPostHomePage(SysPostHomePage sysPostHomePage);

    /**
     * 修改首页配置信息
     * 
     * @param sysPostHomePage 首页配置信息
     * @return 结果
     */
    public int updateSysPostHomePage(SysPostHomePage sysPostHomePage);

    /**
     * 删除首页配置信息
     * 
     * @param id 配置ID
     * @return 结果
     */
    public int deleteSysPostHomePageById(Long id);

    /**
     * 批量删除首页配置信息
     * 
     * @param ids 需要删除的配置ID数组
     * @return 结果
     */
    public int deleteSysPostHomePageByIds(Long[] ids);
}